#!/usr/bin/env python
import os
import json

def main():
    """Script entry point: return some JSON based on calling args.
    We should be called from Jenkins and expect the following to 
    be defined: $TARGET_PRODUCT $JOB_NAME $BUILD_NUMBER $BUILD_URL"""
    target_product=os.environ.get("TARGET_PRODUCT")
    job_name=os.environ.get("JOB_NAME")
    build_number=os.environ.get("BUILD_NUMBER")
    build_url=os.environ.get("BUILD_URL")
    
    # Board-specific parameters
    if target_product == "pandaboard":
        # Board to test on. Let validation worry about load balancing.
        test_target="panda01"
        test_stream="/anonymous/android-daily/"
    #elif target_product == ---> Add other boards here
    else:
        #TODO: We don't know how to test this job, so skip testing.
        print "Should skip testing and output nothing."
        return

    config = json.dumps( { "job_name": build_url,
 "image_type": "android",
 "target": test_target,
 "timeout": 18000,
 "actions": [
  {
    "command": "deploy_linaro_android_image",
    "parameters":
      {
        "boot":
build_url + "/artifact/build/out/target/product/" + target_product + "/boot.tar.bz2",
        "system":
build_url + "/artifact/build/out/target/product/" + target_product + "/system.tar.bz2",
        "data":
build_url + "/artifact/build/out/target/product/" + target_product + "/userdata.tar.bz2"
      },
    "metadata":
      {
        "android.name": job_name, 
        "android.build": build_number, 
        "android.url": build_url
      } 
  },
  {
    "command": "boot_linaro_android_image"
  },
  {
    "command": "0xbench"
  },
  {
    "command": "submit_results_on_host",
    "parameters":
      {
        "server": "http://validation.linaro.org/lava-server/dashboard",
        "stream": test_stream
      }
  }
 ]
}, indent=4)

    print config

if __name__ == "__main__":
    if os.environ.get("LAVA_SUBMIT") > 0:
        main()

